Module s390x

Module s390x 

Constants

BACKCHAIN
Store the address of the caller’s frame into the callee’s stack frame.
CONCURRENT_FUNCTIONS
Assume that the concurrent-functions facility is installed.
CRT_STATIC
Enables C Run-time Libraries to be statically linked.
DEFLATE_CONVERSION
Assume that the deflate-conversion facility is installed.
ENHANCED_SORT
Assume that the enhanced-sort facility is installed.
GUARDED_STORAGE
Assume that the guarded-storage facility is installed.
HIGH_WORD
Assume that the high-word facility is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION3
Assume that the message-security-assist extension facility 3 is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION4
Assume that the message-security-assist extension facility 4 is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION5
Assume that the message-security-assist extension facility 5 is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION8
Assume that the message-security-assist extension facility 8 is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION9
Assume that the message-security-assist extension facility 9 is installed.
MESSAGE_SECURITY_ASSIST_EXTENSION12
Assume that the message-security-assist extension facility 12 is installed.
MISCELLANEOUS_EXTENSIONS_2
Assume that the miscellaneous-extensions facility 2 is installed.
MISCELLANEOUS_EXTENSIONS_3
Assume that the miscellaneous-extensions facility 3 is installed.
MISCELLANEOUS_EXTENSIONS_4
Assume that the miscellaneous-extensions facility 4 is installed.
NNP_ASSIST
Assume that the NNP-assist facility is installed.
TRANSACTIONAL_EXECUTION
Assume that the transactional-execution facility is installed.
VECTOR
Assume that the vectory facility is installed.
VECTOR_ENHANCEMENTS_1
Assume that the vector enhancements facility 1 is installed.
VECTOR_ENHANCEMENTS_2
Assume that the vector enhancements facility 2 is installed.
VECTOR_ENHANCEMENTS_3
Assume that the vector enhancements facility 3 is installed.
VECTOR_PACKED_DECIMAL
Assume that the vector packed decimal facility is installed.
VECTOR_PACKED_DECIMAL_ENHANCEMENT
Assume that the vector packed decimal enhancement facility is installed.
VECTOR_PACKED_DECIMAL_ENHANCEMENT_2
Assume that the vector packed decimal enhancement facility 2 is installed.
VECTOR_PACKED_DECIMAL_ENHANCEMENT_3
Assume that the vector packed decimal enhancement facility 3 is installed.