Constants
- BACKCHAIN
- Store the address of the caller’s frame into the callee’s stack frame.
- CONCURRENT_
FUNCTIONS - Assume that the concurrent-functions facility is installed.
- CRT_
STATIC - Enables C Run-time Libraries to be statically linked.
- DEFLATE_
CONVERSION - Assume that the deflate-conversion facility is installed.
- ENHANCED_
SORT - Assume that the enhanced-sort facility is installed.
- GUARDED_
STORAGE - Assume that the guarded-storage facility is installed.
- HIGH_
WORD - Assume that the high-word facility is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N3 - Assume that the message-security-assist extension facility 3 is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N4 - Assume that the message-security-assist extension facility 4 is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N5 - Assume that the message-security-assist extension facility 5 is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N8 - Assume that the message-security-assist extension facility 8 is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N9 - Assume that the message-security-assist extension facility 9 is installed.
- MESSAGE_
SECURITY_ ASSIST_ EXTENSIO N12 - Assume that the message-security-assist extension facility 12 is installed.
- MISCELLANEOUS_
EXTENSIONS_ 2 - Assume that the miscellaneous-extensions facility 2 is installed.
- MISCELLANEOUS_
EXTENSIONS_ 3 - Assume that the miscellaneous-extensions facility 3 is installed.
- MISCELLANEOUS_
EXTENSIONS_ 4 - Assume that the miscellaneous-extensions facility 4 is installed.
- NNP_
ASSIST - Assume that the NNP-assist facility is installed.
- TRANSACTIONAL_
EXECUTION - Assume that the transactional-execution facility is installed.
- VECTOR
- Assume that the vectory facility is installed.
- VECTOR_
ENHANCEMENTS_ 1 - Assume that the vector enhancements facility 1 is installed.
- VECTOR_
ENHANCEMENTS_ 2 - Assume that the vector enhancements facility 2 is installed.
- VECTOR_
ENHANCEMENTS_ 3 - Assume that the vector enhancements facility 3 is installed.
- VECTOR_
PACKED_ DECIMAL - Assume that the vector packed decimal facility is installed.
- VECTOR_
PACKED_ DECIMAL_ ENHANCEMENT - Assume that the vector packed decimal enhancement facility is installed.
- VECTOR_
PACKED_ DECIMAL_ ENHANCEMENT_ 2 - Assume that the vector packed decimal enhancement facility 2 is installed.
- VECTOR_
PACKED_ DECIMAL_ ENHANCEMENT_ 3 - Assume that the vector packed decimal enhancement facility 3 is installed.